from django.db import models


class TaskResult(models.Model):
    name = models.CharField(max_length=250)

    started_at = models.DateTimeField(auto_now_add=True)
    finished_at = models.DateTimeField(null=True, default=None)

    success = models.BooleanField(null=True, default=None)

    output = models.TextField()

    def __str__(self):
        return self.name

    class Meta:

        index_together = (
            ('name', 'started_at'),
        )



#!/usr/bin/env python
from setuptools import setup

setup(
    name='django_cron_tasks',
    description='Django background tasks, ran via crontab.',
    version='1.0.0',
    packages=['django_cron_tasks'],
    author='Henrik Heino',
    author_email='henrik.heino@gmail.com',
    license='MIT License',
    url='https://github.com/henu/django_cron_tasks',
)



from django.contrib import admin

from . import models

@admin.register(models.TaskResult)
class TaskResultAdmin(admin.ModelAdmin):
    list_display = ('name', 'started_at', 'finished_at', 'success')
    readonly_fields = ('name', 'started_at', 'finished_at', 'success', 'output')
